<?xml version="1.0" encoding="utf-8"?>
<browserconfig>
    <msapplication>
        <tile>
            <square150x150logo
                src="{{ url_for('favicons', path='mstile-150x150.png').path }}" />
            <TileColor>#b91d47</TileColor>
        </tile>
    </msapplication>
</browserconfig>